@@ -28,11 +28,11 @@ let%expect_test "default_max_message_size" =
     {|
     (monitor.ml.Error
      ("Message cannot be sent"
-      ((reason (Message_too_big ((size 7) (max_message_size 1))))
+      ((reason (Message_too_big ((size 8) (max_message_size 1))))
        (connection
         ((description <created-directly>)
          (writer
           ((t ((file_descr _) (info (writer "rpc_test 1")) (kind Fifo)))
-           (max_message_size 1)))))))
+           (max_message_size 1) (total_bytes 0)))))))
      ("<backtrace elided in test>")) |}]
 ;;
